.. _user-guide:

User guide
==========

.. toctree::
    :maxdepth: 1

    installation
    arrays
    groups
    attributes
    storage
    config
    v3_migration

Advanced Topics
---------------

.. toctree::
    :maxdepth: 1

    performance
    consolidated_metadata
    extending


.. Coming soon
    async
